@@ -1,4 +1,4 @@
-__version__ = '0.0.30'
+__version__ = '0.0.31'
 
 DB_VERSION = 1
 
@@ -12,6 +12,8 @@ import threading
 
 g = threading.local()
 
+RLock = threading.RLock
+
 from pathlib import Path
 from functools import partial
 
@@ -75,15 +77,14 @@ class YEDB():
         if debug:
             logger.debug(f'JRPC ({"msgpack" if use_msgpack else "json"}) '
                          f'{self.db} method={method} auth={self.http_auth}')
-        # according to tests, session is 3x slower than singles
-        # try:
-        # post = g.session.post
-        # except AttributeError:
-        # import requests
-        # session = requests.Session()
-        # g.session = session
-        # post = session.post
-        from requests import post
+        try:
+            post = g.session.post
+        except AttributeError:
+            import requests
+            session = requests.Session()
+            g.session = session
+            post = session.post
+        # from requests import post
         r = post(self.db,
                  data=data,
                  headers=headers,
@@ -194,21 +195,21 @@ class YEDB():
             self.default_fmt = default_fmt if default_fmt else DEFAULT_FMT
             self.default_checksums = default_checksums
             self._dbpath_len = len(self.db.absolute().as_posix()) + 1
-            self.lock = threading.RLock()
+            self.lock = RLock()
             self._key_locks = {}
             self._opened = False
             self._flock = None
             self._flock_fh = None
             self.lock_file = (self.db / 'db.lock').absolute()
             self.meta_file = (self.db / '.yedb').absolute()
-            self.safe_write = True
+            self.write_modified_only = True
             self.auto_flush = True
             self.lock_ex = True
             self.force_native_json = False
             self._parse_options(kwargs)
 
     def _parse_options(self, options):
-        for o in ['safe_write', 'auto_flush', 'lock_ex']:
+        for o in ['write_modified_only', 'auto_flush', 'lock_ex']:
             try:
                 val = options[o]
                 if val is not None:
@@ -219,7 +220,6 @@ class YEDB():
     def _init_db(self):
         self.dbinfo = {
             'lock_ex': self.lock_ex,
-            'safe_write': self.safe_write,
             'auto_flush': self.auto_flush,
             'path': Path(self.db),
         }
@@ -408,7 +408,7 @@ class YEDB():
                                             default_fmt=new_fmt,
                                             default_checksums=checksums)
                     new_db.open(lock_ex=False,
-                                safe_write=False,
+                                write_modified_only=False,
                                 auto_flush=False,
                                 _skip_meta=True)
                     new_db.checksums = True if checksums or \
@@ -459,8 +459,6 @@ class YEDB():
             timeout: max open timeout
             auto_create: automatically create db
             auto_repair: automatically repair db
-            safe_write: perform safe writes (check key and write file only if
-                the key is changed)
             auto_flush: always flush written data to disk
             lock_ex: lock database exclusively, so no other thread/process can
                 open it (requires "portalocker" module)
@@ -588,7 +586,7 @@ class YEDB():
             try:
                 l = self._key_locks[name]
             except KeyError:
-                l = threading.RLock()
+                l = RLock()
                 self._key_locks[name] = l
             with l:
                 keypath, keyn = name.rsplit('/', 1) if '/' in name else ('',
@@ -596,7 +594,7 @@ class YEDB():
                 keydir = self.db / keypath
                 keydir.mkdir(exist_ok=True, parents=True)
                 key_file = keydir / (keyn + self.suffix)
-                if self.safe_write:
+                if self.write_modified_only:
                     try:
                         if self.get(name) == value:
                             if debug:
@@ -639,12 +637,12 @@ class YEDB():
             try:
                 l = self._key_locks[name]
             except KeyError:
-                l = threading.RLock()
+                l = RLock()
                 self._key_locks[name] = l
             try:
                 l2 = self._key_locks[new_name]
             except KeyError:
-                l2 = threading.RLock()
+                l2 = RLock()
                 self._key_locks[new_name] = l2
             with l:
                 with l2:
@@ -746,7 +744,7 @@ class YEDB():
             try:
                 l = self._key_locks[name]
             except KeyError:
-                l = threading.RLock()
+                l = RLock()
                 self._key_locks[name] = l
             with l:
                 keypath, keyn = name.rsplit('/', 1) if '/' in name else ('',
@@ -798,7 +796,7 @@ class YEDB():
             try:
                 l = self._key_locks[name]
             except KeyError:
-                l = threading.RLock()
+                l = RLock()
                 self._key_locks[name] = l
             keypath, keyn = name.rsplit('/', 1) if '/' in name else ('', name)
             keydir = self.db / keypath
@@ -822,7 +820,7 @@ class YEDB():
             try:
                 l = self._key_locks[name]
             except KeyError:
-                l = threading.RLock()
+                l = RLock()
                 self._key_locks[name] = l
             keypath, keyn = name.rsplit('/', 1) if '/' in name else ('', name)
             keydir = self.db / keypath
@@ -855,7 +853,7 @@ class YEDB():
             try:
                 l = self._key_locks[name]
             except KeyError:
-                l = threading.RLock()
+                l = RLock()
                 self._key_locks[name] = l
             with l:
                 dn = self.db / name
@@ -1241,8 +1239,8 @@ class KeyDict:
 
     def close(self, _write=True):
         if _write and self._changed:
-            if not self.db.safe_write or self.db.get(self.key_name,
-                                                     {}) != self.data:
+            if not self.db.write_modified_only or self.db.get(
+                    self.key_name, {}) != self.data:
                 if debug:
                     logger.debug(f'requesting to update {self.key_name}')
                 self.db._write(self.key_file, self.db._dump_value(self.data))
@@ -1318,8 +1316,8 @@ class KeyList:
 
     def close(self, _write=True):
         if _write and self._changed:
-            if not self.db.safe_write or self.db.get(self.key_name,
-                                                     {}) != self.data:
+            if not self.db.write_modified_only or self.db.get(
+                    self.key_name, {}) != self.data:
                 if debug:
                     logger.debug(f'requesting to update {self.key_name}')
                 self.db._write(self.key_file, self.db._dump_value(self.data))
